@@ -18,8 +18,9 @@
 #' each group.
 #'
 #' @param data Data frame to sample from
-#' @param n The number of draws to select
-#' @param draw The name of the column indexing the draws
+#' @template param-ndraws
+#' @template param-seed
+#' @param draw The name of the column indexing the draws; default `".draw"`.
 #' @author Matthew Kay
 #' @keywords manip
 #' @examples
@@ -44,21 +45,25 @@
 #'   mtcars %>%
 #'     group_by(cyl) %>%
 #'     data_grid(hp = seq_range(hp, n = 101)) %>%
-#'     add_fitted_draws(m_mpg) %>%
+#'     add_epred_draws(m_mpg) %>%
+#'     # NOTE: only use sample_draws here when making spaghetti plots; for
+#'     # plotting intervals it is always best to use all draws
 #'     sample_draws(100) %>%
 #'     ggplot(aes(x = hp, y = mpg, color = ordered(cyl))) +
-#'     geom_line(aes(y = .value, group = paste(cyl, .draw)), alpha = 0.25) +
+#'     geom_line(aes(y = .epred, group = paste(cyl, .draw)), alpha = 0.25) +
 #'     geom_point(data = mtcars)
 #' }
 #' }
 #' @importFrom dplyr filter
 #' @export
-sample_draws = function(data, n, draw = ".draw") {
+sample_draws = function(data, ndraws, draw = ".draw", seed = NULL) {
   .draw = as.name(draw)
 
   draw_full = data[[draw]]
 
-  draw_sample = sample(unique(draw_full), n)
+  if (!is.null(seed)) set.seed(seed)
+
+  draw_sample = sample(unique(draw_full), ndraws)
 
   filter(data, !!.draw %in% !!draw_sample)
 }
